Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranรฎ)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Brazil)
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
Previously on "The Valley"...
Jason's in no space to be judging anyone's relationship.
Keep your wedding ring on all the time,
and then you can start talking.
[blows raspberry]
Never.
[voice breaking] There's this, like, literal wedge between us,
and I feel completely alone.
Brittany--she said, "Zack got crazy last night.
We had to have him taken out of the bar."
Jax came to the house a couple days ago, uncovered the cameras.
He was spying on you from your own surveillance cameras.
BRITTANY: He has not paid our mortgage since May.
JASMINE: He what?
I'm-a have to lose my dream home.
[voice breaking] I'm-a have to lose my family.
I'm-a have to lose everything.
***
* I'm all right *
* I'm all right *
* Everything is all right *
* Everything is all right *
* I'm all right *
***
***
* Let's have a little competition in the spotlight *
* Don't care if we just... *
Guess what I bought? Cottage cheese.
I got cream cheese. I got booty cheese.
-No! -[laughs] Yeah.
You can have booty cheese for breakfast tomorrow.
I don't wanna have booty cheese!
* Leave your worries on the floor *
Cruzy, come here! You got something in your nose.
* Now you got me wanting more *
[Kingsley barking]
Kingsley, don't start. I don't need it right now.
[sighs] My life. What is my life?
* Ooh, I need to move *
* Take off my shoes *
JANET: Yellow baby.
-Yellow baby. -That one looks purple.
This one's blue.
-This is blue? -Yes.
This looks purple to me.
* Oh, why you wanna do that dance in front of me? *
* Why you wanna do that dance in front of me? *
-I'm making shots right now. -JANET: Shots?
I got a little hair of the dog goin'.
-I'm so excited for enchiladas. -SCHEANA: Yes.
I'll put 'em in the oven while everyone's in the pool,
and then we feast.
This is my first time having Scheana's famous enchiladas.
-'Cause he was vegan! -I was vegan the first time.
-Hi! -Hello!
-Pretty dress. -Thank you. You look cute.
Hi!
-Hi, Jason. [laughs] -Hey, Brittany. How you doing?
Good. How are you? Well, hello! [laughs]
Um, Jax has been texting me today.
-Oh, God. -Just--he just said,
"Hey, are you guys okay?" And I said, "Yeah, we're okay.
We're dealing with our own stuff,
but proud of you for staying in there."
Please, God, stay in there. So over it.
I think I was holding on to a lot of hope
that rehab would really help him.
I still wanted him to fight for me a little bit.
Hi!
-Hi, baby. Mwah. -How are ya?
-I'm good. -[laughter]
-How are you feeling? -I'm kind of numb.
Yeah. What's the big--
Just got too much going on where I can't even, like, focus
on things right now, so...
-I'm sorry. -Just moving slow.
Him just going and signing this lease without talking to me
and knowing that I still had this rental home
for two and a half more months,
like, he just really screwed me over.
Well, I'm gonna go play with Summer.
That's as slow as it gets.
So, if you guys wanna come hang out, we'll be outside.
I need to move on. I just know I deserve better.
[laughter]
Last night was heavy, though.
I mean, it was just a lot of like, bam, bam, bam, bam, bam.
I was having fun until the cameras left.
What happened?
I don't know. Where do we even begin?
At Brittany's shark party, after filming ended,
Scheana was talking to Zack. -That looks crazy.
-I know. I just so... -It looks real.
I know. Aly does such a good job.
I know. I'm glad I didn't do it.
She mentioned Jared and Zack
said some pretty horrible things.
I can't even repeat what he said.
Why don't you just say like, he should go [bleep] himself?
Just be a little bit nicer, not so wildly offensive.
JANET: Jared.
BRITTANY: He thinks that I'm always picking
their side over his side.
-Like, I'm with Zack a lot. -Yeah.
So, I don't know why he still feels that way.
-Yeah. -And I think that that's why
he was saying, "You're a bad--" Like, last night whenever
he texted me, was saying I was a bad friend
because I'm not picking...
-His side. -...his side.
***
I thought I said, "Jared can go [bleep] himself."
-KRISTEN: Mm-hmm. -She says I said
something more aggressive.
Brittany then came out and was like,
"What did you say?" Like, so aggressively.
-And I'm like... -Yeah.
I'm sorry. Is hyperbole dead? Brittany knows me.
Like, if I'm talking, and I'm angry,
nothing I'm saying is out of pocket or out of what--
Like, I'm not threatening anybody.
Can we get that out of it?
Like, there's no threats going on.
That would trigger me if she came up to me and said,
"What did you say?" or "What did you do?"
I would be like, "How about ask them?
Stop ----ing asking me how I started it."
And I used the word "hyperbole," right?
No, they don't.
But I want America to learn.
So, America, today's word is "hyperbole."
-[harp plays glissando] -Look it up.
Sometimes I feel like Brittany doesn't...hear me
or, like, because she knows I'm always gonna be there,
she just--
She kinda doesn't ----ing care.
Yeah. That's it.
That's it.
When I moved to L.A. by myself,
Brittany was the only person I knew.
To me, that's my family.
I definitely have missed having that connection.
Sometimes I feel like I've lost a part of myself
because I don't have her the way I used to have her.
Things have just-- are just different.
-There does have to be a talk. -KRISTEN: Yeah.
There does have to be something.
This is how we fix it.
-I hope so. -[stifles laugh]
***
SCHEANA: I'll put the enchiladas in the oven.
JANET: [singsongy] Enchiladas!
All right. Setting timer.
How long do they have to cook for?
Til the cheese is, like, super melted.
But I do, like, 25, 30 minutes usually.
-Can I vent about yesterday? -Yeah.
Good, you're here for this. Do you have your wedding ring on?
Well, I'm gonna sit over there with you.
-I mean... -Playa, playa.
Most of the ring off.
Kristen, in a roundabout way, told us...
-Yeah. [laughing] -...that she heard from Jasmine
that Jason goes to bars and takes off his wedding ring.
-Like, implying that there's... -Implying that I'm out here...
I'm out, like--I'm out, like, at LAX hotel bars just, like,
picking up flight attendants or something.
-Flight attendants. -Trust me, if there's a husband
in this group that's trying to cheat and failing,
it's not mine. -No.
-Let me say that. Okay? -Unh-unh.
I'm both impressed and annoyed with how good Kristen is
at creating distractions
and filling up bullsh-- in a room
to distract from the truth.
Now you're gonna have people talking about Jason
and what kind of husband he is, and if he's going to the bars
and being shady, and what are we not talking about?
Danny actually going to the bars and being shady.
Jasmine was invited today,
and she didn't come becauseof you.
Well, here's the real thing.
Jasmine made this sh-- up, and then she told Kristen
because she wanted to get back at Janet
for whatever she wanted to get back at Janet for.
And now that Kristen said it,
she's scrambling for ways to say that she didn't just make it up.
That is not my friend.
If Jason ever took off his ring, it was probably be like,
"I've had a little too much sodium today.
Like, my fingers are swelling," you know? [laughs]
-Like, you would never do that. -Jasmine knows him.
Jasmine knows him, too. She knows his character.
-He wouldn't do that. Like... -JANET: Kristen knows him.
-[laughs] -The other thing is too, like,
when--when I first heard this, I just kind of laughed it off,
and I didn't really, like, realize,
but then when I sat with it and thought about it more,
I got a little more upset.
When we got back to see my mom and Cameron after yesterday,
we were, like, laughing it off.
I was like, ha ha. Like, Kristen and Jasmine started
this little thing that Jason, like, takes his ring off.
My mom was like, "They said what?"
And she got, like, visibly upset.
-Yeah. -And then this morning,
I was like, wait, this is bullsh--.
I expect bullsh-- to come spewing out
of Kristen Doute's mouth. I don't expect it from Jasmine.
Unless Jasmine apologizes for making this up,
I cannot move forward with her.
-Same. And I'm sorry. -JASON: And I'm sorry.
Has Kristen Doute ever apologized
for anything in her ----ing life?
No. She's sorry that she got caught.
Girl came after my husband.
Good luck. You just put a target on your back, bitch.
Hey, Janet, are you done?
SCHEANA: Whoo! Let's eat, bitches!
I'm ready for some enchiladas now.
SCHEANA: All right.
Coming up...
Why do you have this giant thing?
-It's a metal detector. -What are you gonna find?
***
* Feel so free now *
***
* It's so right *
* Let me out *
***
You know how to use it? Like, you remember how to turn it on?
Yeah. Okay. I'm trying to think if we should
go closer to the water or closer to the fire pits.
Ooh.
Where do you think people lose stuff?
-Good call. -[beeping]
-Ooh. -Oh. Okay.
-[beeping continues] -Okay. So, where exactly?
-So, I mean, right here? -Yeah.
-Hey, wait, stop. -Oh.
-What is it? -Bottle cap. See if that's it.
Whoo. Yeah, that is it. That's kind of fun, though.
[Jason laughs]
-Oh, here's Brittany. -Hello!
-Hey! -I found a bottle cap.
BRITTANY: When did you get that thing?
I got it for my 30th birthday from my mom.
-[laughs] Shut up. -Hey, Brittany, how you doing?
-Hi! -How was your drive over here?
[sighs] Took like an hour and a half.
-Yeah. -Oh, no.
We got chips and snacks and s'mores.
-Yum. You have s'mores? -Oh, s'mores? Awesome.
I was thinking about that on the way here.
Yes. Did you find anything with your metal detector?
Just a bottle cap that I'm gonna keep
because I'm so excited about it. -That is so funny.
MICHELLE: Oh, careful.
Is that Michelle and Aaron? I thought that was Kristen.
JASON: It's definitely Michelle and Aaron.
-Oh, yes, Michelle and Aaron. -I'm gonna help Aaron.
He's got--lugging a cooler. [laughs]
-Hi, girl. -Hey!
-Hi. You look so cute. -You got furs and all.
-[laughs] -It's super windy.
-Have you talked to Jasmine? -No.
I told her that you guys want an apology and stuff,
and she's not here for it. She said that...
-Brittany, what did she say? -Jasmine's gonna double down.
-She's getting nothing from me. -You know why?
Oh, Lord.
I heard it from a bunch of other people.
Who am I gonna go to her and be like,
"Jason's taking off his ring"? 'Cause it didn't matter to me.
I'm not really sure why people have had issues with Janet.
She's been there for me no matter what.
I don't see her as this big drama starter and stuff
like everybody else does because
that's just not my friendship that I have with her.
But she did say she didn't even think it's true.
I'm just letting you know.
Either way, somebody who makes something up or takes something
she doesn't think is true and runs to someone
I'm not talking to at the time and repeats it,
that's not a friend. -Yeah.
I don't pay attention when I walk.
-I have no sense of direction. -[laughs]
Like when I used to go to the Grove all the time
before I used to valet, I would lose my car every time.
-Hey! [laughs] -I'm gonna go to the bathroom.
Today is going to be a sh--show.
It's cold. It's windy.
Jasmine's over Janet. I'm over Janet.
-Sh--'s heavy. -Hey, guys!
Oh, you got wood. Look at you!
-Hey. -[laughs]
The rumor about Jason taking his ring off--
Janet was fine with it at Brittany's party,
[blows raspberry] Never.
But now I heard from a little birdie, AKA Scheana...
-[bird chirping] -...that Janet is talking sh--.
I mean, I did bring up the ring rumor about her and Jason.
Stop talking about Danny and Nia,
and I won't have to come for you.
That was the first time I've opened these.
That was a mistake.
Hi, Britt.
-Hi! -Hi, honey.
You like my little backpack chair?
Yeah. [laughs] That's such, like, a beach mom thing.
LUKE: We're setting up over there?
These aren't put together, by the way--these chairs.
-No, you just--It's really easy. -Is it?
Do you want me to pull up the directions?
I got it. I got it.
Whoo!
Brittany said that Janet is demanding an apology.
And all I can think is Janet can shove
that apology up her ass because she's not getting one from me.
***
I didn't start anything, so why am I apologizing? For what?
And I didn't bring it up to you, so again,
what am I apologizing for?
[crunching]
Hi!
-BRITTANY: Hi, guys! -Sorry we're so late.
-That's all right. -I don't live over here anymore.
Lala, I swear, you are just killing the pregnancy.
SCHEANA: I know. That's bomb.
-So freaking cute. -BROCK: Hey, brother.
Brittany, you drove here?
-Yeah. -SCHEANA: Wait, that's so cute.
KRISTEN: What? You hate driving. This is really far.
-It is really far -In really sh--ty traffic.
I got a hot date after this. Why you think I'm so dressed up?
-Wait. -[laughter]
-You have a hot date after this? -Brittany.
-Yeah. -He's so hot.
Nice.
Things have been so terrible between me and Jax,
and I just feel like there's no going back.
And now I just need to, like, put myself first.
And I've got a crush on somebody. [laughs]
I haven't felt, like, butterflies or anything
like that in a long time.
So, you know, it's nice.
Are you going somewhere over this way?
I'm just gonna go to my rental.
Why do you have this giant thing?
-It's a metal detector. -What are you gonna find?
Oh, there's a lot of metals around here.
Janet had her metal detector all around this fire pit.
-It's loaded. -You're gonna find, like,
people lose their wedding rings and stuff.
-Let's play Truth or Dare. -JANET: I'm not getting naked.
BROCK: Why do we wanna be playing Truth or Dare?
BRB.
-Okay, truth or dare, Janet? -Truth.
I'm not doing this. And then she making little comments.
[mockingly] "You wanna talking about taking a ring off?"
Bitch, say what you gotta say to my face right now.
What was the craziest sex you've ever had?
-Oh. -[laughter]
Obviously missionary in bed with Jason.
Nope! In your-- In your life, girl.
Just say nothing at all right now.
Okay, Scheana, truth or dare?
-Truth. -How big is Brock's dick?
-[laughter] -JASMINE: You hear her?
[laughs] Like, this doesn't make sense to me.
-Show us, you know-- -No, it's the girth,
I feel like, that matters more than the length.
It's not this, okay?
-It perfectly fits in all holes. -[laughter]
I just can't. I just can't.
But after one, I did get hemorrhoids, so that's a...
-Ow! -You got hemorrhoids
after he put it in your butt?
MICHELLE: Wait, what? I missed that.
She got hemorrhoids after he put it in her butt.
-Yeah. -Oh, my God.
So, then when I got 'em again after I had Summer,
I was like, oh, been there.
-[laughter] -He's a grower, not a shower.
-[laughter continues] -A hundred percent a grower.
-That's, like, the worst... -[laughter continues]
Michelle, truth or dare.
MICHELLE: I knew this bitch was gonna call me.
What's your most embarrassing thing
that's ever happened during sex?
MICHELLE: Embarrassing?
Have you ever gotten it up the butt?
[laughter]
No. Janet!
[laughter continues]
***
[Kristen sighs]
***
Marshmallow first, then the chocolate.
-Marshmallow always first. -Yeah, and then chocolate later.
And then you put graham cracker, chocolate.
-Yeah, yeah, but not now. -And then you put that on.
-Wait till it's done. -Yeah, when it's done.
Bitch, I haven't done this sh-- in so long.
BROCK: Have you done this before?
JASON: What do you wanna do?
If she wants to make it right, we're here. We showed up.
It's not up to us to initiate conversations, I think,
with somebody who clearly doesn't give a sh-- about us.
JASON: Maybe something's being lost in the grapevine.
Let's go directly to the source and see if she wants to talk.
-Yeah. -You ready?
-BROCK: You didn't get your bag. -My mom, she made me--
She's like, "You have to do this for college."
-And I was like, what? -I need, like, one more minute.
One more minute? Okay.
And I'm a Girl Scout for life. I have a membership, too.
Isn't that crazy? Never used it, but I still have it. I'm alumni.
-All right, wanna go? -Yeah.
-[bleep] -[indistinct conversations]
-Ask her if she wants to talk. -JASON: Yeah.
JANET: 'Cause she may not even want to.
***
Hey, Jasmine. You have a minute to chat?
***
Coming up...
Janet, you have been a sh--ty ass friend.
You are a ----ing vibe killer. You're exhausting.
[laughter]
[sighs]
What do you wanna do?
If she wants to make it right, we're here. We showed up.
It's not up to us to initiate conversations, I think,
with somebody who clearly doesn't give a sh-- about us.
JASON: Maybe something's being lost in the grapevine.
Let's go directly to the source and see if she wants to talk.
-Yeah. -You ready?
JASON: Hey, Jasmine. You have a minute to chat?
Yeah, of course. Yeah.
-Let's go away and, uh... -Yeah, yeah, no, of course.
-...and private talk. -Hundred percent.
I don't want people's impression of me to be that I'm
this dirtbag who goes out cruising for chicks.
And for Jasmine to be the one who put that out there
in the first place, it's really hurtful.
All right, so I'm, like, really confused about a lot of stuff.
-Yeah. -Like...
-What do you wanna know? -What's going on?
The ring thing-- I heard it years ago.
I didn't care then, and I don't care now.
-How many years ago? -Let me finish, Janet.
You're not cutting me off 'cause this is what you do.
-Let's--done, done, done. -Janet, Janet, stay--stay--
-Let me talk, Janet! -Wait, Jasmine.
-You're yelling. You're yelling. -I'm talking--I'm yelling now
because you--this is what-- you walked away.
All she did was ask a follow-up question.
I just asked a question. You're yelling.
No, you said, "Let's go."
Wait, she's being defensive right now, Janet.
Because I just asked you a question.
I'm talking to Jason right now.
-Let me talk to him. -Well, don't be so defensive.
-Okay. -Where did you hear about it?
I heard it from a group of friends. I'm not a snitch.
I'm not snitching on people. There was something going on.
Melissa heard it, too. A lot of people did, and I didn't care.
So, you heard this rumor two years ago,
and then you just sat on it?
No, listen, the fact that it was brought up, that sucks.
But I'm telling you for a fact, I did not believe it then.
-I don't believe it now. -What do you mean,
"It was brought up. That sucks"? What does that mean?
-No, I'm saying, like, that-- -You brought it up to Kristen.
Whatever. The fact that it was brought up, I don't care.
-You brought it up. -Janet, I need you
to shut up right now. -Jasmine, all right.
Because my problem--No, no, no. I'm about to get loud right now.
-Jasmine, we're not--wait. -Get loud.
I just wanna say something. You don't need to get loud.
-No one's getting loud. -That's why he
was defending you. -I'm trying to talk to you.
But she's like... "Duh-duh-duh, duh-duh-duh."
I'm asking questions. Okay, Jason.
-Let me say my other thing. -I'm not--I'm walking away.
Janet, you have been a sh--ty ass friend.
You are a ----ing vibe killer. You're exhausting.
You give Karen energy, and I'm ----ing done with it.
[music warps down]
Good riddance to my beach day.
JASON: Were you not at our home for 4th of July?
-We're done! We're done! -Oh, Lord.
I'm listening to you, but my ears are over there.
We're done. It's not even about that.
-Holding our baby-- -Jason, shut up!
-I didn't make up this sh--! -What happened?
-Jason, you're not... -No, Janet.
I'm done. You're not gonna make me be like this.
Everyone needs to know this. Everyone here,
this is the fakest, most two-faced--
-I've looked out for you. -It's not ----ing fake!
I've looked out for you forever!
I know you have. I'm not talking about you!
I'm talking about her right now!
I've always looked at you like a sister.
-You took him down! -You've broken my heart!
-Oh, my God, Jason. I... -You've broken my heart.
-I broke your heart? -You did!
-Your friends said it! -You're a liar.
-Let's leave. Let's go. -Talk to your friends!
JANET: Jasmine's a mess. Jason?
Jason? Let's go.
This seems like Jasmine has not only, like, despises Janet,
but, like, has for a long time.
And it's just making me second-guess
our entire relationship and think, like, how much
of this was fake and how much of it is real?
Have fun looking yourself in the mirror talking sh--
about every single person here to every other person here.
-What are you talking about? -You're two-faced.
We all talk about each other! Shut the hell up!
No, we don't! I don't talk about anybody!
I'm a regular person! I don't talk sh-- about anybody!
For somebody who I've invested in a relationship,
I really value that. That means a lot to me.
This whole thing is, it's like-- it's like a different side
of Jasmine that's--that I don't know who brought it out of her
because Janet and I haven't done anything to her.
-It was two years ago! -I can't believe that, like,
the biggest snake in the grass
has been under my nose this whole time.
Okay, yes, I'm the biggest snake. Ooh, big deal.
Jason, it's not about you right now.
I've always cared about you so much.
-She's not worth it. -He's not understanding.
-He's not listening. -She's not a friend.
-Janet's all, like, saying sh--. -She's a two-faced person.
I can't even have a conversation with Janet.
We're getting outta here. Love you guys.
Love my actual friends. You don't talk sh-- about me.
Your friends weren't ----ing with you at the time, okay?
-I will. Love you guys. -Talk to your boys, not me,
'cause I already know. They're my family.
They don't [bleep] with you. They don't like you.
Showed us exactly who she is.
***
And now I don't have to have any loyalty to her.
This is the best beach day I've ever had.
You know what's crazy, too, that pisses me off?
At the party, I said this to Jason.
-He goes, "That makes sense." -But then they said
that you made it up. That's what they told Jason.
JASMINE: Listen, no, no, no, no. Nope.
Listen, Scheana, Jasmine did not tell me.
-Just so everyone knows. -Trust me, I don't do that.
Who's this random group of guys she's even talking about?
She's fake. That was insane.
I love Jason. Like, the sh-- I have with Janet
I have other sh-- I need to talk to her about, but I can't
'cause she ----ing wants to storm away.
I'm talking to Jason about it.
I'm like, "Jason," trying to, like, you know.
'Cause I get emotional because I like him.
And then Janet's like, "You're fake. You're fake."
I'm like, "Would you shut up so I can talk to him?"
I think Janet's so used to me being that friend that kind of
just takes her sh--, dumps things on me,
manipulates me, whatever.
And I kind of just, like, brush it off.
And now Jason doesn't wanna have a one-on-one conversation
with me because Janet won't allow it,
'cause Janet can't let Jason do anything by himself, clearly.
I'm not doing this.
I'm not doing it.
Like, I'm just so annoyed because I knew her way back
before half all you guys, back. -Way before I knew her, yeah.
So, I cherished that.
But now I'm like, you won't even let me talk to you.
I've never had an issue with Jason.
We look out for each other,
being the only Black people in the group.
Like, we have each other's back and we just, like, have this,
like, language like, you know, we kiki and joke about things.
They're over here saying they're hurt, and I'm like,
well, I'm hurt, too. I'm a little emotional about it.
So, I'm trying not to get emotional about it
'cause it pisses me off.
[bleep]
I've known Jasmine for a long time, and...
it's hard for me to really talk about it right now
because it's just like, it was shocking, I mean...
JANET: We were friends with her for seven years.
-Yeah. -As long as I've known Scheana,
he's been friends with her.
And the fact that I can't even be like,
"You said it. Why'd you say it?"
He's so whipped. I know he's not doing sh--.
Correct.
Why is this even being brought up?
We already squashed all this. I didn't bring it up.
-I don't know. I don't know. -That's what we were asking.
-I don't know. -I did not bring it up.
That's what everyone's trying to figure out.
I'm done. She acted like she was our friend.
Wow, have you felt this way about me for a long time,
and I just haven't noticed?
Like, it really feels like you don't give a sh-- about me.
We are not friends. We haven't been in a while.
I mean, it--it's hurtful.
-Bye, Karen. -Bye. Thanks.
Nah. Too soon. Way too soon. Way too soon.
-[laughter] -Coming up...
Anytime that something small happens,
you'd be like, "well, she likes Janet better than me."
But that's not true.
***
-Welcome to NoHo Arts District. -Oh, my God. It's so pretty.
This is actually where, like, a lot of the dancers live.
All the dance studios are over here.
MAN: Hello. Welcome in.
-Hey. -Hello.
It smells like vanilla lattes and deliciousness in here.
Yeah, I got to go. I'm walking up to order some food.
-Oh, hi. -Hi.
Sorry, babysitter convo with Daniel.
Uh, quickly. What's up? Quickly, quickly.
KRISTEN: Can I do the Beca without bacon?
-MAN: Bacon. -[singsongy] Hello!
I'm also gonna get a morning bun.
-Hi. -[grunts]
Hi!
-I love this color on you. -Thank you. Enjoy.
-Where are we going? -I didn't, so yes.
-Out back. -Out back? Okay.
-BRITTANY: Oh, wow. -NIA: Cute little patio.
Oh, this is way bigger than I thought it was.
What a fun little place.
And it's the one place where they value shade in L.A.
Does everybody want water? Oh, you don't really want--
-I don't want water. -Yeah, he doesn't drink water.
-He's weird. -Or ice.
-Is it gonna... -[laughs]
-I know. -Last night at, um...
BRITTANY: Yeah, what did you guys do?
We went to a great little, like, outdoor bar place
with, like, games to play.
-Yay! -Downwind.
-It's downwind. -Let's go, baby.
***
-Oh, that is-- -What the mother...
-I almost said it on Riverside. -I'm just strong.
-Very fun. -It was a great night.
-I really wish I had been there. -This looks beautiful.
-Thank you. -Thank you so much.
It's not a Casamigos shot. [laughs]
-KRISTEN: Thank you. -Okay.
And this is Beca with the bacon.
BRITTANY: Thank you so much!
How was your evening after the beach?
Whoo-hoo! It was great.
Tell me, what was that? What happened?
I've just been hanging out with this new guy.
-Mm-hmm? -And I really like him.
-[mouth full] Amazing. -He's a dad.
-Mm. -And he's got a real job
and real responsibilities, and he's like, super...
-...motivated. -How'd you meet him?
Hosting a "Bachelorette" Monday at Jax's.
-At Britt's Bar. -At Britt's bar.
-At Britt's Bar. -Mm-hmm, mm-hmm.
He's just got completely different qualities
than Jax has. I mean, sending me
a "good morning" text-- that should not be like,
"Oh, my God, he sent me a 'good morning' text."
But it's, like, little things like that that Jax didn't do
for me for years that make the biggest difference.
-He's so cute, too. -NIA: Yeah.
-Like, sexy. -No, he's hot.
We're just hanging out and having fun.
A little Peacock and chill. [laughs]
[laughter]
Oh, I love when you're laughing and smiling...
-Yeah. -...and having fun again.
-He makes me smile. -God bless it.
-Love that. -Really wish I had been there.
-NIA: How was the beach? -I thought the beach was fun,
but I know Kristen didn't think it was fun. But... [laughs]
I did not think it was fun.
Jasmine and Luke and I did not think it was fun.
-Really? -Uh, no.
To me, it's comical that Janet and Jason,
after laughing it off at your party,
all of a sudden are making it this huge deal...
Yeah, it's confusing.
...and now saying that Jasmine fully made it up,
which is not true whatsoever,
because I had heard it separately.
Which is what I think Jasmine was trying to say last night.
But for some reason, they think that Jasmine made it up.
Honestly, I feel like maybe him and Janet,
like, had some conversations, and they--
you know how you can, like, spiral down, like, rabbit holes,
and I feel like maybe that's what happened.
Janet, you didn't let Jason off his leash.
How could he cheat? Like, come on, let's be real.
-That's what upsets me. -I feel like she wants to stir
the pot, and I'm like, but why? -But that's what upsets me.
-Why would you do that? -I honestly give zero ----s.
When you both shut it down, to me, it's over.
-Mm-hmm. -So, when you bring it back up,
now it looks a little weird.
I hope that they can figure this out
'cause they've been friends for a long time.
Janet wants to, like, dig her heels in.
And, I mean, I think this is gonna lead
into our next conversation anyway, but...
I just have still been feeling like if Jax does something bad,
in the past, you always would hide it or, like, downplay it
or whatever, or, like, protect him in that moment.
Even with Janet, you do it in the moment.
You're like, "Oh, no, she didn't. She didn't.
Oh, like, poor Janet. Like, blah, blah, blah."
Heaven forbid I do or say or step out of line in any way.
I'm either held to this different standard
or that you don't specifically have my back in the moment.
I mean, do I think that Zack is right
in having an issue that Janet comes between he and Brittany?
Yeah, I see that. I also feel the same way about Janet
and my friendship with Brittany.
-I was pretty shocked. -Because Kristen and I
are your best friends. -I mean, in tier.
And by best, I mean, like, top tier of the shelf
that Jared and Janet are,
is, like, in the back of the-- like, at the very bottom
with the dust webs. -In your opinion.
You guys are all my best friends.
I'm very lucky that I have so many close friends in my life.
But guess what? If I'm talking to them,
I'm gonna tell you your guys' point of view.
I do the exact same thing, I promise you.
The Brittany that I knew in the past is not the Brittany
that I am here with today,
and it kind of sucks because we've been through so much.
And I don't know why she has pushed me away
when I'm always the one she calls in a crisis,
when I've been nothing but supportive,
and I've never once faltered in our friendship.
I don't want you to, like,
anytime that something small happens, you'd be like,
"Well, she likes Janet better than me."
'Cause that's not true.
[coughs] Ooh. Visceral reaction.
***
Coming up...
I'm so tired of anger. I'm so tired of yelling,
but I also pushed her away.
***
-This is it. -This is it.
-LA Tox. -I love, like, a detox
and a lymphatic massage. -Oh, man, these are painful.
-This is cool. -Hello! Wow.
-Such a vibe. -How's it going?
-How are you guys? -Good.
-Is this just lymphatic massage? -It is.
-Have you both done it before? -I have.
Yes. I need a lot of detox in this, like, season of life.
-You're in for a treat. -NIA: Okay, great.
-DANNY: All right, all right. -So, let's take you back.
-We're excited. Oh, boy. -We're gonna have you
change in here. -Okay.
A lymphatic drainage massage is supposed to release
and drain toxins from your body.
Let's just look at this light real quick.
Oh, yeah, there we go.
Which is great, 'cause it's been a toxic couple of weeks
dealing with... a couple toxic people.
-Wait, is that your affirmation? -It is.
NIA: "I am smart. I am beautiful. I am strong."
DANNY: "I am perfectly myself."
I am perfectly myself.
I don't feel perfectly myself yet, you know?
Aw. Well, you are perfectly yourself.
-Nope. -Oh. Okay.
I'm just letting you know. Thanks for trying.
-Um, but I'm working on it. -I hear ya.
I had to change my body, stretch my body.
My body has to recover.
Boobs aren't where I want them to be.
Skin on the stomach is loose. All those things.
You have never heard me complain.
Doesn't help what's going on in my own head.
No, I hear ya.
I don't want our children to be spaced far apart in years.
And if we're gonna have more,
I don't wanna wait multiple years.
I feel like it's putting pressure on you,
but also, I'm the one that has to carry the baby.
I want you to be happy, and I think the first step is,
you know, go get checked... -Yeah.
...with your fertility doctor and see where we're at.
That will happen soon, yeah.
Um, and then we can fully decide on something.
***
If we're gonna have another baby,
I wanna do it soon.
You can't do a mommy makeover if you're gonna have another kid.
I just wanna feel good in my skin again.
How's the bed? Is it nice and comfortable?
-The bed is great. -Wonderful.
A heads up, if your other customer over there
is talking too much, we might need to move rooms.
-[chuckles] Take a deep inhale. -[inhales deeply]
-...and exhale. -[exhales deeply]
-NIA: Detox and relax. -[Danny snoring loudly]
No thinking about children.
[exhales deeply]
Having a fourth child...
four under four. [chuckles]
NIA: You can ask for less, honey.
[strained voice] I'm here for the experience. Oh, my gosh.
Aah!
I ain't got the bandwidth for this right now
in our current state of where we're living.
-Oh, Kelly Clarkson. -What? [laughs]
Ow! Stop! Aah.
I still am looking for that big house
that can accommodate our 17 children.
That's where my head is still at.
Oh, my gosh. [cries]
-Aw. -Um... [chuckles]
I'm gonna give you guys some privacy to get dressed.
-How do you feel? -I'm ready for my happy ending
that you said you were gonna give me.
-Oh, my gosh. -[laughs]
You had that before we arrived.
[laughs]
***
* Show 'em out through the town *
JASON: What are you guys doing in there?
I don't know. It's kind of fun in here.
It's kind of funny. [kisses]
-Thank God for him, huh? -Oh.
I don't know how you would've gotten through today
if you didn't have him. -I haven't been in a situation
since he's been born where I've been, like,
crying all day or for, like, hours at a time.
He can sense that I'm upset, and I don't want him--
Yeah, you can't-- You don't want that energy.
-No. -'Cause he's such a happy baby.
I know.
***
[voice breaking] I, like, was looking today
at, like, these pictures of, like--see? He knows.
[sniffles]
Come here.
-Oh, you wanna go to Dada? -Go to Dada?
When we were talking to her, the way that she looked at you
and spoke to you was if, like, you were just, like,
the scum of the earth. -[fussing]
[crying] I just, like, don't understand what's going on.
[Cameron fusses]
***
Like, this hurts really bad. It feels like...
It feels like being dumped out of nowhere. [sniffles]
Jasmine's been a close friend for many years,
and I feel like she's kind of discarding our friendship.
I don't wanna cry in front of him.
I might take him over to my mom's for a little bit.
-I'll take him. -She doesn't have the same care
for me that I have for her, so it's honestly really sad.
-[door opens] -He's with your mom.
-Is he happy? -Yeah, he was happy.
-Yeah, every time. -It doesn't matter who it is,
if it's of the three of us, but if you're new.
If you're new, it's the biggest smile.
[cellphone chimes]
So, I have, like, five missed calls from Jax.
[sighs] Call him back. But has he been FaceTiming you or what?
He's been calling me. I'm just gonna FaceTime him.
Okay. Can I be, like, not in it where, like--
Yeah, yeah.
[line rings]
-[cellphone chimes] -What's up, man?
-How are you? -How you doing? How you feeling?
What are you doing, just learning and growing
every day or what? What's going on in there?
Today was kind of a rough day.
Um, just kind of with my therapy.
I mean, overall, it's been really, really good,
really, really helpful, and I got into some old stuff today.
I'm just trying to really figure out
where my anger's coming from.
I'm so tired of anger. I'm so tired of yelling.
I lost it all when I found out about Julian.
My best friend-- yes, that's awful.
But I also pushed her away.
I pushed her away, and I didn't even ----ing see it.
-Well... -Like, I didn't--
I didn't even realize what I was doing. Like, I just was--
I've gotten away with it for so long that I found this
to be acceptable behavior, and it's obviously not.
And coming here, and it's a wake-up call.
And, like, I know how I grew up.
[voice breaking] I have to think my dad put me here for a reason
because he's like, "Enough's enough.
You're gonna do what you did, I did to you."
And I just--I wanna break the cycle. I really, really do.
Hurts, man.
There's so much hurt. Like, look at the sh-- that
I put her through, the sh-- storm.
I live for my kid.
[voice breaking] Literally, the only thing I even care about
in this world. -Okay, don't cry.
There's no reason. That's the alcohol.
Well, it's making me sad. I can't even have an emotion.
No, you can't. How much was she drinking on the boat?
-Zero. -Zero.
Jax, I can ----ing hear you. Everybody here has my back,
and you're my ----ing husband and you're trying to make me
look like I'm a bad person?
I'm so used to treating her like sh--
that I just didn't even see it
because she let me get away with it for so long.
I wish I was more-- I was held more accountable.
I wish Brittany would have left me a ----ing long time ago.
[sniffles]
I'm hearing an acknowledgement from Jax that he realizes
that his behavior was inappropriate
and has been inappropriate for a while.
It's a good start,
and I'm hopeful that it's the beginning of change.
I feel like it's a baby step in the right direction,
and we'll see what happens from here.
I will say this, though,
if you want to make strides with Brittany
and, like, get this going, I know something that's really
been weighing and stressing her out is the mortgage.
She says that, like, it hasn't been paid in a while.
And if you could-- I think that would be
a really good step forward if you can get up to date
on the mortgage. Um-- -Well, I have--
I have a situation for that. Um...
I talked to my manager, and she just
gets the full amount until we pay off
what needs to be paid off.
Now I just don't have the funds just to pay off what I owe.
-That's the best way to do it. -That makes sense.
I mean, I gotta say, I've talked to you a few times
when you've been in here.
This is the first time where I've talked to you where
you've literally taken full accountability for things
and not said like, "I messed up, but Brittany did this,"
or "I messed up, but this happened."
Like, you're taking full accountability.
Like, this is--I'm seeing a legitimate change.
This place has just made me realize that, sh--,
-I-I need to wake up here. -This is great to hear, man.
This is the best call I've ever had with you.
Jax is someone who I care about,
and I wanna see him do well in life,
and, um, it--he wasn't doing well for a little while there.
And on that call, it really felt like a turning point for him.
It felt like he had an epiphany and just really saw
exactly what was happening and was ready to make changes.
I really am proud of you.
And I hope I get to see you the day I get outta here.
Maybe we'll go get a haircut or something.
-I don't know. I need a haircut. -[laughing] I mean, oh, yeah.
All right, man. I love you, buddy.
All right. Take care of yourself.
-You, too. -And give my best to Janet.
-And, um, I'll talk to you soon. -I will. Talk to you soon.
-All right. -All right. Bye.
[cellphone bloops]
Man.
That was...
That...that hit.
-Like, that was... -Yeah.
He got me, too.
-That was-- -What is up with me?
-[laughs] I know. -I'm just crying, like, nonstop.
I've cried, like, 20 times in the last, like, five days.
-[sighs] -I think I'm sleep-deprived.
I love you.
* Na-na, na-na *
* Na-na, na-na, na-na *
* Ooh-ooh-ooh, ooh *
* Ooh, ooh-ooh-ooh *
-[dog barks] -Hey, chill out.
[barking continues]
* Na-na-na, ooh-ooh-ooh *
* Ooh, ooh-ooh-ooh *
Oh. Yep.
-Mom! -Huh?
-Come here. -Well, hang on just a second.
I need you to hold my ladder. [chuckles]
Now that Jax is moving into the condo,
which I'm still so pissed about, at least from all of this,
me and Cruz get to move back into our house where we belong.
I'm taking over the mortgage, even though I've already got
two and a half more months paid up in this rental,
so I'm paying double now.
He's hid the ladder from me so that I cannot replace the stuff.
What a weirdo.
All right, well, we're just gonna stand on this.
-Okay. -Crazy.
He's not gonna spy on me
whenever he had it covered the entire time.
Two can play this game, buddy.
-Now he's blocked by Brittany. -Yeah.
[laughter]
My plan moving forward is my rental is just gonna
sit there vacant for two and a half months.
Luckily, I'm doing okay, and I can afford it right now.
But, like, I gotta figure something out,
'cause it's-- that's a lot of money.
Let's call Auntie Jenny, buddy.
[line rings]
Let's say hi to Auntie Jenny. Rawr!
Look, there's Auntie!
Aw, look how long his hair is.
-I know. It's so long. -Come here.
-Aw! -I'm gonna see if he wants
to get a snack or something. -Okay.
I wanna catch up with you, obviously, on everything.
I know we've talked, like, here and there,
but, um, did I tell you that he hasn't paid
the mortgage since May?
-Yeah. -Yeah.
I did hear. Yeah.
My wedding ring and my wedding bands are missing.
They're not in the safe. They're nowhere in the house. Nothing.
-Don't know where they-- -They're missing?
Yeah, don't know where they are.
Like, what? I don't understand.
What--
Yeah?
Sorry, one second.
"Make sure you get that on film. I can hear everything.
Childish behavior."
He can't hear. You can't hear anything.
Do you think that he put a bug in here?
Oh, God!
***
[laughs]
Jenny! Why is he like this?
Unless he put some little secret devices around this house,
our interior cameras don't have sound.
Come here.
BRITTANY: But we are speaking about Jax Taylor here.
I don't put anything past him anymore.
-JENNY: Oh, he's calling me. -Jax is?
-Yeah. -Okay, well, I love you.
You can talk to him, and, uh, we'll just--
let's stay in contact these next couple days for sure.
-Bye! -All right, bye.
[whispers] Jesus.
Let's go in. Let's go get something to eat.
-Wanna get something to eat? -[cellphone rings]
Oh, wait, Jenny's calling me back.
-[cellphone chimes] -What happened?
-He's going to the hospital. -What do you mean?
His blood pressure is, like, super high.
-What? Why? -You guys putting stickers--
you and Sherri.
Well, yeah, I was re-covering the cameras, obviously.
Is he even really doing that,
or is he just trying to freak me out?
I could hear that they were driving.
My biggest fear before he got in there was
I was thinking he was gonna have a heart attack.
Both my uncles have died before the age of 50.
God. Even as mad and angry as him--at him as I am,
I don't want anything to happen to him.
-I know. -Ugh!
I know.
All right, just please, like, text me.
-Okay, sounds good. -I love ya.
Love you, too. Talk to you soon.
All right, bye. Mom, come over here.
Okay.
Uh, Jax just wrote me this really long email
saying that, "In terms of the mortgage, I've been trying
to contact the bank to pay off what is owed,
but they let me know the home is in foreclosure,
and after this month, I will not be paying anything more.
You will be responsible until we sell the house."
[laughs] What?
When Jax does things like this, it's so hard to know what's real
or if he's just wanting attention.
-Why are you responsible? -What a fool.
I was always hopeful that being in the facility
would make some kind of change or open his eyes a little bit
to do something better, but based on his behavior,
the whole time he's been in there,
I am so worried that he has not learned a damn thing.
And he's, like, saying, we share the podcast 50/50.
He just told Janet and Jason that he was gonna let me
have all the money from the podcast.
Oh, my gosh.
I talked to my manager, and she gets the full amount
until we pay off what needs to be paid off.
He's not even done the podcast in how long?
No, he hasn't done the podcast in, like, two or three months.
I've done everything. But now look at him.
How can he do this to me?
[voice breaking] What in the world did I--
did I do to deserve any of this?
You didn't do anything, Brittany.
* Back and forth we go *
* Up and down we're so *
-* Back and forth we go * -Cruzy!
* Up *
We're gonna be all right, buddy.
Give Mommy loves. Give Mommy love!
Don't you lick that booger. Don't you lick that booger.
Oh. I love you.
-* Back and forth we go * -Mwah.
Mommy's got us. Mommy's got us.
-Mwah. -* Back and forth we go *
* Up and down and round will this go *
***
Next time on "The Valley"...
I'm pretty excited to walk out that door.
I have anxiety. I'm anxious. I'm scared.
I do think filing for divorce, the sooner the better.
I mean, could I start the filing process today?
You can, absolutely.
KRISTEN: Welcome to your bar, my love.
Wait! What have you guys done?
-[cheering] -Shut up.
Look at Janet just going in right now.
-Stop. -JASON: I don't know
what's going on with you right now, but it's--
-What did you just say? -I'm out.
You're being ----ing weird right now. Just relax.
This is Dark Side Danny at his finest.
-Wow. -Not "Wow," dude.
-JANET: We have nothing to hide. -[Danny laughs]
My husband's not the one out here grabbing asses.
***
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.